akhdefo_functions.plot_stackNetwork — Akhdefo software documentation

# akhdefo_functions.plot_stackNetwork

akhdefo_functions.plot_stackNetwork(src_folder='', output_folder='', cmap='tab20', date_plot_interval=(5, 30), marker_size=15)

  This Program plots temporal network of triplets to be stacked for calculating Annual Mean Velocity from stacked optical images.

  ## Parameters

  src_folderstr

    path to georeferenced_folder

  output_folderstr

    path to output folder to save output Figure plot

  cmapstr

    colormap for the plot default is “tab20”

  date_plot_intervallist

    minumum and maximum plot x axis interval dates for the plot

  marker_sizefloat

    size of plotted points default is 15

  ## Returns

  Figure